#include <3664.h>

// AA 55 AA 55
// DATA_A0 DATAB0 - DATA_A255 DATA_B255
// PORT8
//
// +---+---+---+---+---+---+---+---+
// |P87|P86|P85|P84|P83|P82|P81|P80|
// +---+---+---+---+---+---+---+---+
// |OUT|               | 0 : 50KS/s|
// |   |               | 1 : 5KS/s |
// |   |               | 2 : 500S/s|
// +---+---------------+-----------+

unsigned char CArrayA[256];
unsigned char CArrayB[256];
unsigned char CValueA;
unsigned char CValueB;
int ICount;

void initialize(void);
void sendData(void);
void sendChar(unsigned char);

void int_timerv(void){
  if (ICount < 256){
    CArrayA[ICount] = CValueA;
    CArrayB[ICount] = CValueB;
    ICount++;
  }
  
  IO.PDR8.BIT.B7 = !IO.PDR8.BIT.B7;
  if (TV.TCSRV.BIT.CMFA) TV.TCSRV.BIT.CMFA = 0;
}

void main(){

  initialize();
  EI;

  while(1){
    
    if (AD.ADCSR.BIT.ADF){
      CValueA = AD.ADDRA >> 8;
      CValueB = AD.ADDRB >> 8;
      AD.ADCSR.BIT.ADF = 0;
    }
    
    if (ICount >= 256){
      sendData();

      switch (IO.PDR8.BYTE & 0x07){
        case 0:
          TV.TCRV0.BIT.CKS = 0x01;
          TV.TCRV1.BIT.ICKS = 0;
          TV.TCORA = 79;
          break;
        case 1: 
          TV.TCRV0.BIT.CKS = 0x02;
          TV.TCRV1.BIT.ICKS = 0;
          TV.TCORA = 199;        
          break;
        case 2:
          TV.TCRV0.BIT.CKS = 0x03;
          TV.TCRV1.BIT.ICKS = 1;
          TV.TCORA = 249;
          break;
        case 3: break;
        case 4: break;
        default: break;
      }
    }
  }
}

void initialize(){ 
  int i;
  AD.ADCSR.BYTE = 0x19;
  AD.ADCR.BYTE = 0x00;
  AD.ADCSR.BIT.ADST = 1;

  IO.PCR8 = 0x80;

  TV.TCRV0.BIT.CMIEA = 1;
  TV.TCRV0.BIT.CCLR = 0x01;
  TV.TCRV0.BIT.CKS = 0x01;
  TV.TCRV1.BIT.ICKS = 0;
  TV.TCORA = 79;

  IO.PMR1.BIT.TXD = 1;
  SCI3.SCR3.BIT.TE = 0;
  SCI3.SCR3.BIT.RE = 0;
  SCI3.SCR3.BIT.CKE = 0x00;
  SCI3.SMR.BYTE = 0x00;
  SCI3.BRR = 51;
  for (i = 0; i < 30000; i++){}
  SCI3.SCR3.BIT.TE = 1;
  
  ICount = 0;
}

void sendData(){
  int i;
  sendChar(0xaa);
  sendChar(0x55);
  sendChar(0xaa);
  sendChar(0x55);
  
  for (i = 0; i < 256; i++){
    sendChar(CArrayA[i]);
    sendChar(CArrayB[i]);
  }
  sendChar(IO.PDR8.BYTE & 0x7f);
  
  ICount = 0;
}

void sendChar(unsigned char ucData){
  while(!SCI3.SSR.BIT.TDRE);
  SCI3.TDR = ucData;
}  
